@@ -59,7 +59,7 @@ BEGIN
     our $VERSION = 'v0.2.0';
 };
 
-use strict;
+# use strict;
 no warnings 'redefine';
 
 sub new
@@ -73,6 +73,7 @@ sub op
 {
     no overloading;
     my( $self, $other, $swap, $op ) = @_;
+    no strict;
     my $dt1 = $self->{dt};
     my $dt2;
     if( Scalar::Util::blessed( $other ) && $other->isa( 'DateTime' ) )
@@ -83,12 +84,12 @@ sub op
     {
         $dt2 = $other->{dt};
     }
-    ## Might trigger an error if this does not work with DateTime, but that's the developer's problem
+    # Might trigger an error if this does not work with DateTime, but that's the developer's problem
     elsif( Scalar::Util::blessed( $other ) )
     {
         $dt2 = $other;
     }
-    ## Unix time
+    # Unix time
     elsif( $other =~ /^\d{10}$/ )
     {
         $dt2 = DateTime->from_epoch( epoch => $other, time_zone => 'local' );
